
<template>
  <view-grid ref="grid" :columns="columns" :detail="detail" :editFormFields="editFormFields"
    :editFormOptions="editFormOptions" :searchFormFields="searchFormFields" :searchFormOptions="searchFormOptions"
    :table="table" :extend="extend">
  </view-grid>
</template>
<script>
import extend from "@/extension/basicinfo/Dt_StationManager.js";
import { ref, defineComponent } from "vue";
export default defineComponent({
  setup() {
    const table = ref({
      key: "stationID",
      footer: "Foots",
      cnName: "站台信息",
      name: "Dt_StationManager",
      url: "/Dt_StationManager/",
      sortName: "stationID",
    });
    const editFormFields = ref({
      stationCode: "",
      stationName: "",
      stationMaterial: "",
      stationEnable: "",
      stationArea: "",
      stationRemark: "",
      deviceCode: "",
    });
    const editFormOptions = ref([
      [
        {
          title: "站台编号",
          field: "stationCode",
          type: "int",
        },
        {
          title: "站台名称",
          field: "stationName",
          type: "string",
        },
        {
          title: "站台类型",
          required: true,
          field: "stationMaterial",
          type: "select",
          dataKey: "agvStationEnum",
          data: [],
        },

      ],
      [
        {
          title: "区域",
          required: true,
          field: "stationArea",
          type: "select",
          dataKey: "agvareaEnum",
          data: [],
        },
        {
          title: "是否启用",
          required: true,
          field: "stationEnable",
          type: "select",
          dataKey: "enable",
          data: [],
        },
        {
          title: "备注",
          field: "stationRemark",
          type: "string",
        },
      ], [
        {
          title: "所属设备",
          field: "deviceCode",
          type: "string",
        },

      ]
    ]);
    const searchFormFields = ref({
      stationCode: "",
      stationName: "",
      stationMaterial: "",
      stationEnable: "",
    });
    const searchFormOptions = ref([
      [
        { title: "站台名称", field: "stationName", type: "like" },
        { title: "站台编号", field: "stationCode", type: "like" },

        {
          title: "站台类型",
          field: "stationMaterial",
          type: "select",
          dataKey: "agvStationEnum",
          data: [],
        }
      ],
      [
        { title: "所属设备", field: "deviceCode", type: "like" },
        {
          title: "区域",
          field: "stationArea",
          type: "select",
          dataKey: "agvareaEnum",
          data: [],
        }, {
          title: "是否启用",
          field: "stationEnable",
          type: "select",
          dataKey: "enable",
          data: [],
        },
      ],
    ]);
    const columns = ref([
      {
        field: "stationId",
        title: "stationId",
        type: "int",
        width: 90,
        hidden: true,
        readonly: true,
        require: true,
        align: "left",
        sort: true
      },
      {
        field: "stationCode",
        title: "站台编号",
        type: "string",
        width: 100,
        align: "left",
        sort: true
      },
      {
        field: "stationName",
        title: "站台名称",
        type: "string",
        width: 150,
        align: "left",
        sort: true
      },
      {
        field: "stationMaterial",
        title: "站台类型",
        type: "string",
        width: 150,
        align: "left",
        bind: { key: "agvStationEnum", data: [] },
        sort: true
      },
      {
        field: "stationEnable",
        title: "是否启用",
        type: "string",
        width: 120,
        align: "left",
        bind: { key: "enable", data: [] },
        sort: true
      },
      {
        field: "stationArea",
        title: "区域",
        type: "string",
        width: 120,
        align: "left",
        sort: true,
        bind: { key: "agvareaEnum", data: {} }
      },
      {
        field: "stationRemark",
        title: "备注",
        type: "string",
        width: 120,
        align: "left",
        sort: true
        // link: true,
      },
      {
        field: "deviceCode",
        title: "所属设备",
        type: "string",
        width: 120,
        align: "left",
        sort: true
      },
    ]);
    return {
      table,
      extend,
      editFormFields,
      editFormOptions,
      searchFormFields,
      searchFormOptions,
      columns,
    };
  },
});
</script>
      